@@ -3,27 +3,29 @@
 #[derive(Debug)]
 #[non_exhaustive]
 pub enum Error {
-    /// The exhaustive list of MeiliSearch errors: https://github.com/meilisearch/specifications/blob/main/text/0061-error-format-and-definitions.md
-    /// Also check out: https://github.com/meilisearch/MeiliSearch/blob/main/meilisearch-error/src/lib.rs
+    /// The exhaustive list of Meilisearch errors: <https://github.com/meilisearch/specifications/blob/main/text/0061-error-format-and-definitions.md>
+    /// Also check out: <https://github.com/meilisearch/Meilisearch/blob/main/meilisearch-error/src/lib.rs>
     MeiliSearchError {
         /// The human readable error message
         error_message: String,
         /// The error code of the error.  Officially documented at
-        /// https://docs.meilisearch.com/errors.
+        /// <https://docs.meilisearch.com/errors>.
         error_code: ErrorCode,
         /// The type of error (invalid request, internal error, or authentication
         /// error)
         error_type: ErrorType,
-        /// A link to the MeiliSearch documentation for an error.
+        /// A link to the Meilisearch documentation for an error.
         error_link: String,
     },
 
-    /// There is no MeiliSearch server listening on the [specified host]
+    /// There is no Meilisearch server listening on the [specified host]
     /// (../client/struct.Client.html#method.new).
     UnreachableServer,
-    /// The MeiliSearch server returned an invalid JSON for a request.
+    /// The Meilisearch server returned an invalid JSON for a request.
     ParseError(serde_json::Error),
-    /// This MeiliSearch SDK generated an invalid request (which was not sent).
+    /// A timeout happened while waiting for an update to complete.
+    Timeout,
+    /// This Meilisearch SDK generated an invalid request (which was not sent).
     /// It probably comes from an invalid API key resulting in an invalid HTTP header.
     InvalidRequest,
 
@@ -41,15 +43,15 @@ pub enum Error {
 pub enum ErrorType {
     /// The submitted request was invalid.
     InvalidRequest,
-    /// The MeiliSearch instance encountered an internal error.
+    /// The Meilisearch instance encountered an internal error.
     Internal,
     /// Authentication was either incorrect or missing.
-    Authentication,
+    Auth,
 }
 
 /// The error code.
 ///
-/// Officially documented at https://docs.meilisearch.com/errors.
+/// Officially documented at <https://docs.meilisearch.com/errors>.
 #[derive(Debug, Clone)]
 #[non_exhaustive]
 pub enum ErrorCode {
@@ -88,13 +90,18 @@ pub enum ErrorCode {
     MalformedPayload,
     InvalidContentType,
     MissingPayload,
+    MissingParameter,
+    InvalidApiKeyDescription,
+    InvalidApiKeyActions,
+    InvalidApiKeyIndexes,
+    InvalidApiKeyExpiresAt,
+    ApiKeyNotFound,
 
     /// That's unexpected. Please open a GitHub issue after ensuring you are
-    /// using the supported version of the MeiliSearch server.
+    /// using the supported version of the Meilisearch server.
     Unknown(UnknownErrorCode),
 }
 
-
 #[derive(Clone)]
 pub struct UnknownErrorCode(String);
 
@@ -111,22 +118,22 @@ impl std::fmt::Debug for UnknownErrorCode {
 
 impl ErrorType {
     /// Converts the error type to the string representation returned by
-    /// MeiliSearch.
+    /// Meilisearch.
     pub fn as_str(&self) -> &'static str {
         match self {
             ErrorType::InvalidRequest => "invalid_request",
             ErrorType::Internal => "internal",
-            ErrorType::Authentication => "authentication",
+            ErrorType::Auth => "auth",
         }
     }
-    /// Converts the error type string returned by MeiliSearch into an
+    /// Converts the error type string returned by Meilisearch into an
     /// `ErrorType` enum. If the error type input is not recognized, None is
     /// returned.
     pub fn parse(input: &str) -> Option<Self> {
         match input {
             "invalid_request" => Some(ErrorType::InvalidRequest),
             "internal" => Some(ErrorType::Internal),
-            "authentication" => Some(ErrorType::Authentication),
+            "auth" => Some(ErrorType::Auth),
             _ => None,
         }
     }
@@ -134,7 +141,7 @@ impl ErrorType {
 
 impl ErrorCode {
     /// Converts the error code to the string representation returned by
-    /// MeiliSearch.
+    /// Meilisearch.
     pub fn as_str(&self) -> &str {
         match self {
             ErrorCode::IndexCreationFailed => "index_creation_failed",
@@ -172,11 +179,17 @@ impl ErrorCode {
             ErrorCode::MalformedPayload => "malformed_payload",
             ErrorCode::InvalidContentType => "invalid_content_type",
             ErrorCode::MissingPayload => "missing_payload",
+            ErrorCode::MissingParameter => "missing_parameter",
+            ErrorCode::InvalidApiKeyDescription => "invalid_api_key_description",
+            ErrorCode::InvalidApiKeyActions => "invalid_api_key_actions",
+            ErrorCode::InvalidApiKeyIndexes => "invalid_api_key_indexes",
+            ErrorCode::InvalidApiKeyExpiresAt => "invalid_api_key_expires_at",
+            ErrorCode::ApiKeyNotFound => "api_key_not_found",
             // Other than this variant, all the other `&str`s are 'static
             ErrorCode::Unknown(inner) => &inner.0,
         }
     }
-    /// Converts the error code string returned by MeiliSearch into an `ErrorCode`
+    /// Converts the error code string returned by Meilisearch into an `ErrorCode`
     /// enum. If the error type input is not recognized, `ErrorCode::Unknown`
     /// is returned.
     pub fn parse(input: &str) -> Self {
@@ -216,6 +229,11 @@ impl ErrorCode {
             "malformed_payload" => ErrorCode::MalformedPayload,
             "invalid_content_type" => ErrorCode::InvalidContentType,
             "missing_payload" => ErrorCode::MissingPayload,
+            "invalid_api_key_description" => ErrorCode::InvalidApiKeyDescription,
+            "invalid_api_key_actions" => ErrorCode::InvalidApiKeyActions,
+            "invalid_api_key_indexes" => ErrorCode::InvalidApiKeyIndexes,
+            "invalid_api_key_expires_at" => ErrorCode::InvalidApiKeyExpiresAt,
+            "api_key_not_found" => ErrorCode::ApiKeyNotFound,
             inner => ErrorCode::Unknown(UnknownErrorCode(inner.to_string())),
         }
     }
@@ -246,10 +264,11 @@ impl std::fmt::Display for Error {
                 error_message,
                 error_link,
             ),
-            Error::UnreachableServer => write!(fmt, "The MeiliSearch server can't be reached."),
+            Error::UnreachableServer => write!(fmt, "The Meilisearch server can't be reached."),
             Error::InvalidRequest => write!(fmt, "Unable to generate a valid HTTP request. It probably comes from an invalid API key."),
             Error::ParseError(e) => write!(fmt, "Error parsing response JSON: {}", e),
             Error::HttpError(e) => write!(fmt, "HTTP request failed: {}", e),
+            Error::Timeout => write!(fmt, "A task did not succeed in time."),
         }
     }
 }
@@ -258,7 +277,6 @@ impl std::error::Error for Error {}
 
 impl From<&serde_json::Value> for Error {
     fn from(json: &serde_json::Value) -> Error {
-
         let error_message = json
             .get("message")
             .and_then(|v| v.as_str())
@@ -274,7 +292,7 @@ impl From<&serde_json::Value> for Error {
         let error_type = json
             .get("type")
             .and_then(|v| v.as_str())
-            .and_then(|s| ErrorType::parse(s))
+            .and_then(ErrorType::parse)
             .unwrap_or(ErrorType::Internal);
 
         // If the response doesn't contain a type field, the error type
@@ -283,7 +301,7 @@ impl From<&serde_json::Value> for Error {
         let error_code = json
             .get("code")
             .and_then(|v| v.as_str())
-            .map(|s| ErrorCode::parse(s))
+            .map(ErrorCode::parse)
             .unwrap_or_else(|| {
                 ErrorCode::Unknown(UnknownErrorCode(String::from("missing error code")))
             });
