@@ -7,48 +7,79 @@ use serde_json::{from_str, to_string};
 pub(crate) enum Method<T: Serialize> {
     Get,
     Post(T),
+    Patch(T),
     Put(T),
     Delete,
 }
 
 #[cfg(not(target_arch = "wasm32"))]
-pub(crate) async fn request<Input: Serialize + std::fmt::Debug, Output: 'static + DeserializeOwned>(
+pub(crate) async fn request<
+    Input: Serialize + std::fmt::Debug,
+    Output: 'static + DeserializeOwned,
+>(
     url: &str,
     apikey: &str,
     method: Method<Input>,
-    expected_status_code: u16
+    expected_status_code: u16,
 ) -> Result<Output, Error> {
+    use isahc::http::header;
     use isahc::*;
 
     trace!("{:?} on {}", method, url);
 
+    let auth = format!("Bearer {}", apikey);
+
     let mut response = match &method {
-        Method::Get => Request::get(url)
-            .header("X-Meili-API-Key", apikey)
-            .body(())
-            .map_err(|_| crate::errors::Error::InvalidRequest)?
-            .send_async().await?,
-        Method::Delete => Request::delete(url)
-            .header("X-Meili-API-Key", apikey)
-            .body(())
-            .map_err(|_| crate::errors::Error::InvalidRequest)?
-            .send_async().await?,
-        Method::Post(body) => Request::post(url)
-            .header("X-Meili-API-Key", apikey)
-            .header("Content-Type", "application/json")
-            .body(to_string(&body).unwrap())
-            .map_err(|_| crate::errors::Error::InvalidRequest)?
-            .send_async().await?,
-        Method::Put(body) => Request::put(url)
-            .header("X-Meili-API-Key", apikey)
-            .header("Content-Type", "application/json")
-            .body(to_string(&body).unwrap())
-            .map_err(|_| crate::errors::Error::InvalidRequest)?
-            .send_async().await?,
+        Method::Get => {
+            Request::get(url)
+                .header(header::AUTHORIZATION, auth)
+                .body(())
+                .map_err(|_| crate::errors::Error::InvalidRequest)?
+                .send_async()
+                .await?
+        }
+        Method::Delete => {
+            Request::delete(url)
+                .header(header::AUTHORIZATION, auth)
+                .body(())
+                .map_err(|_| crate::errors::Error::InvalidRequest)?
+                .send_async()
+                .await?
+        }
+        Method::Post(body) => {
+            Request::post(url)
+                .header(header::AUTHORIZATION, auth)
+                .header(header::CONTENT_TYPE, "application/json")
+                .body(to_string(&body).unwrap())
+                .map_err(|_| crate::errors::Error::InvalidRequest)?
+                .send_async()
+                .await?
+        }
+        Method::Patch(body) => {
+            Request::patch(url)
+                .header(header::AUTHORIZATION, auth)
+                .header(header::CONTENT_TYPE, "application/json")
+                .body(to_string(&body).unwrap())
+                .map_err(|_| crate::errors::Error::InvalidRequest)?
+                .send_async()
+                .await?
+        }
+        Method::Put(body) => {
+            Request::put(url)
+                .header(header::AUTHORIZATION, auth)
+                .header(header::CONTENT_TYPE, "application/json")
+                .body(to_string(&body).unwrap())
+                .map_err(|_| crate::errors::Error::InvalidRequest)?
+                .send_async()
+                .await?
+        }
     };
 
     let status = response.status().as_u16();
-    let mut body = response.text().await.map_err(|e| crate::errors::Error::HttpError(e.into()))?;
+    let mut body = response
+        .text()
+        .await
+        .map_err(|e| crate::errors::Error::HttpError(e.into()))?;
     if body.is_empty() {
         body = "null".to_string();
     }
@@ -57,22 +88,28 @@ pub(crate) async fn request<Input: Serialize + std::fmt::Debug, Output: 'static
 }
 
 #[cfg(target_arch = "wasm32")]
-pub(crate) async fn request<Input: Serialize + std::fmt::Debug, Output: 'static + DeserializeOwned>(
+pub(crate) async fn request<
+    Input: Serialize + std::fmt::Debug,
+    Output: 'static + DeserializeOwned,
+>(
     url: &str,
     apikey: &str,
     method: Method<Input>,
-    expected_status_code: u16
+    expected_status_code: u16,
 ) -> Result<Output, Error> {
     use wasm_bindgen::JsValue;
-    use web_sys::{Headers, RequestInit, Response};
     use wasm_bindgen_futures::JsFuture;
+    use web_sys::{Headers, RequestInit, Response};
 
     trace!("{:?} on {}", method, url);
 
+    const CONTENT_TYPE: &str = "Content-Type";
+    const JSON: &str = "application/json";
+
     // The 2 following unwraps should not be able to fail
 
     let headers = Headers::new().unwrap();
-    headers.append("X-Meili-API-Key", apikey).unwrap();
+    headers.append("Authorization: Bearer", apikey).unwrap();
 
     let mut request: RequestInit = RequestInit::new();
     request.headers(&headers);
@@ -84,14 +121,19 @@ pub(crate) async fn request<Input: Serialize + std::fmt::Debug, Output: 'static
         Method::Delete => {
             request.method("DELETE");
         }
+        Method::Patch(body) => {
+            request.method("PATCH");
+            headers.append(CONTENT_TYPE, JSON).unwrap();
+            request.body(Some(&JsValue::from_str(&to_string(body).unwrap())));
+        }
         Method::Post(body) => {
             request.method("POST");
-            headers.append("Content-Type", "application/json").unwrap();
+            headers.append(CONTENT_TYPE, JSON).unwrap();
             request.body(Some(&JsValue::from_str(&to_string(body).unwrap())));
         }
         Method::Put(body) => {
             request.method("PUT");
-            headers.append("Content-Type", "application/json").unwrap();
+            headers.append(CONTENT_TYPE, JSON).unwrap();
             request.body(Some(&JsValue::from_str(&to_string(body).unwrap())));
         }
     }
@@ -148,7 +190,10 @@ fn parse_response<Output: DeserializeOwned>(
             }
         };
     }
-    warn!("Expected response code {}, got {}", expected_status_code, status_code);
+    warn!(
+        "Expected response code {}, got {}",
+        expected_status_code, status_code
+    );
     match from_str(&body) {
         Ok(e) => Err(Error::from(&e)),
         Err(e) => Err(Error::ParseError(e)),
